==> v0.3.0.tar.gz: powershell/src/Microsoft.PowerShell.Commands.Utility/commands/utility/FormatAndOutput/OutGridView/ColumnInfo.cs <==
#if !CORECLR
//
//    Copyright (C) Microsoft.  All rights reserved.
//
namespace Microsoft.PowerShell.Commands
{
    using System;
    using System.Management.Automation;
    using System.Management.Automation.Internal;

    internal abstract class ColumnInfo
    {
        protected string displayName;
        protected string staleObjectPropertyName;

        internal ColumnInfo(string staleObjectPropertyName, string displayName)
        {
            this.displayName = displayName;
            this.staleObjectPropertyName = GraphicalHostReflectionWrapper.EscapeBinding(staleObjectPropertyName);
        }

        internal string StaleObjectPropertyName()
        {
            return this.staleObjectPropertyName;
        }

        internal string DisplayName()
        {
            return this.displayName;
        }

        internal abstract Object GetValue(PSObject liveObject);

        internal Type GetValueType(PSObject liveObject, out object columnValue)
        {
            columnValue = GetValue(liveObject);
            if(columnValue != null && columnValue is IComparable)
            {
                return columnValue.GetType();
            }
            return typeof(string); // Use the String type as default.
        }

        /// <summary>
        /// Auxiliar used in GetValue methods since the list does not deal well with unlimited sized lines
        /// </summary>
        /// <param name="src">source string</param>
        /// <returns>the source string limited in the number of lines</returns>
        internal static object LimitString(object src)
        {
            string srcString = src as string;
            if (srcString == null)
            {
                return src;
            }

            return HostUtilities.GetMaxLines(srcString, 10);
        }
    }
}
#endif

==> v6.2.5.tar.gz: powershell/src/Microsoft.PowerShell.Commands.Utility/commands/utility/FormatAndOutput/OutGridView/ColumnInfo.cs <==
// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.

namespace Microsoft.PowerShell.Commands
{
    using System;
    using System.Management.Automation;
    using System.Management.Automation.Internal;

    internal abstract class ColumnInfo
    {
        protected string displayName;
        protected string staleObjectPropertyName;

        internal ColumnInfo(string staleObjectPropertyName, string displayName)
        {
            this.displayName = displayName;
            this.staleObjectPropertyName = GraphicalHostReflectionWrapper.EscapeBinding(staleObjectPropertyName);
        }

        internal string StaleObjectPropertyName()
        {
            return this.staleObjectPropertyName;
        }

        internal string DisplayName()
        {
            return this.displayName;
        }

        internal abstract object GetValue(PSObject liveObject);

        internal Type GetValueType(PSObject liveObject, out object columnValue)
        {
            columnValue = GetValue(liveObject);
            if (columnValue != null && columnValue is IComparable)
            {
                return columnValue.GetType();
            }

            return typeof(string); // Use the String type as default.
        }

        /// <summary>
        /// Auxiliar used in GetValue methods since the list does not deal well with unlimited sized lines.
        /// </summary>
        /// <param name="src">Source string.</param>
        /// <returns>The source string limited in the number of lines.</returns>
        internal static object LimitString(object src)
        {
            string srcString = src as string;
            if (srcString == null)
            {
                return src;
            }

            return HostUtilities.GetMaxLines(srcString, 10);
        }
    }
}
